==> 0.0.17.tar.gz: lib/widgets/edit_text.dart <==
import 'package:ampos_ui_library/ampos_ui_library.dart';
import 'package:ampos_ui_library/widgets/text_widget.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class EditText extends Container {
  EditText({
    TextEditingController controller,
    ValueChanged<String> onChanged,
    double width = double.infinity,
    double height = 56,
    int maxLines = 1,
    TextInputType keyboardType = TextInputType.text,
    TextInputAction textInputAction = TextInputAction.none,
    String label,
    Color labelColor = Colors.white,
    double labelSize = FontSize.small,
    FontWeight labelWeight = FontWeight.bold,
    double textSize = FontSize.normal,
    Color textColor = AmposColors.textPrimary,
    FontWeight textWeight = FontWeight.w300,
    bool enabled = true,
    String hint,
    Color backgroundColor = Colors.white,
    EdgeInsets margin = const EdgeInsets.all(0),
    EdgeInsets padding = const EdgeInsets.all(0),
  }) : super(
          width: width,
          height: height,
          margin: margin,
          padding: padding,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Visibility(
                visible: label != null,
                child: TextWidget(
                  label ?? '',
                  size: labelSize,
                  weight: labelWeight,
                  color: labelColor,
                ),
              ),
              Container(
                margin: EdgeInsets.only(top: 8),
                child: TextField(
                  keyboardType: keyboardType,
                  textInputAction: textInputAction,
                  maxLines: maxLines,
                  enabled: enabled,
                  onChanged: onChanged,
                  style: TextStyle(color: textColor, fontSize: textSize, fontWeight: textWeight),
                  controller: controller,
                  cursorColor: textColor,
                  cursorWidth: 1,
                  decoration: InputDecoration(
                    contentPadding: EdgeInsets.all(12),
                    enabledBorder: OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.transparent, width: 0),
                      borderRadius: BorderRadius.all(Radius.circular(4)),
                    ),
                    focusedBorder: OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.transparent, width: 0),
                      borderRadius: BorderRadius.all(Radius.circular(4)),
                    ),
                    border: OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.transparent, width: 0),
                      borderRadius: BorderRadius.all(Radius.circular(4)),
                    ),
                    filled: true,
                    hintStyle: TextStyle(
                      color: textColor.withOpacity(0.6),
                      fontSize: textSize,
                    ),
                    hintText: hint ?? '',
                    fillColor: backgroundColor,
                  ),
                ),
              ),
            ],
          ),
        );
}

==> 0.0.32.tar.gz: lib/widgets/edit_text.dart <==
import 'package:ampos_ui_library/ampos_ui_library.dart';
import 'package:ampos_ui_library/widgets/text_widget.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class EditText extends Container {
  EditText({
    TextEditingController controller,
    ValueChanged<String> onChanged,
    double width = double.infinity,
    double height = 56,
    TextInputType keyboardType = TextInputType.text,
    TextInputAction textInputAction = TextInputAction.none,
    String label,
    Color labelColor = Colors.white,
    double labelSize = FontSize.small,
    FontWeight labelWeight = FontWeight.bold,
    bool enabled = true,
    bool obscureText = false,
    String hint,
    Color backgroundColor = Colors.white,
    EdgeInsets margin = EdgeInsets.zero,
    EdgeInsets padding = EdgeInsets.zero,
  }) : super(
          width: width,
          height: height,
          margin: margin,
          padding: padding,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Visibility(
                visible: label != null,
                child: TextWidget(
                  label ?? '',
                  fontSize: labelSize,
                  fontWeight: labelWeight,
                  color: labelColor,
                  height: 1.2,
                ),
              ),
              Container(
                margin: EdgeInsets.only(top: 8),
                child: TextField(
                  keyboardType: keyboardType,
                  textInputAction: textInputAction,
                  maxLines: 1,
                  enabled: enabled,
                  autocorrect: false,
                  obscureText: obscureText,
                  onChanged: onChanged,
                  style: TextStyle(
                    color: AmposColors.outerSpace,
                    fontSize: FontSize.large,
                    fontWeight: FontWeight.w300,
                  ),
                  controller: controller,
                  cursorColor: AmposColors.outerSpace,
                  cursorWidth: 1,
                  decoration: InputDecoration(
                    contentPadding: EdgeInsets.all(12),
                    enabledBorder: OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.transparent, width: 0),
                      borderRadius: BorderRadius.all(Radius.circular(4)),
                    ),
                    focusedBorder: OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.transparent, width: 0),
                      borderRadius: BorderRadius.all(Radius.circular(4)),
                    ),
                    border: OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.transparent, width: 0),
                      borderRadius: BorderRadius.all(Radius.circular(4)),
                    ),
                    filled: true,
                    hintStyle: TextStyle(
                      color: AmposColors.outerSpace.withOpacity(0.6),
                      fontSize: FontSize.large,
                      fontWeight: FontWeight.w300,
                    ),
                    hintText: hint ?? '',
                    fillColor: backgroundColor,
                  ),
                ),
              ),
            ],
          ),
        );
}
